API docs for “spamfighter.api.message.test.test_firewall”

# Module s.a.m.t.test_firewall

Part of spamfighter.api.message.test View Source

Тесты на `spamfighter.api.message.firewall`.

Class | FakeFirewallCommand | Undocumented
Class | FirewallCommandTestCase | Тест на `spamfighter.api.message.firewall.FirewallCommand`.
Class | FirewallRulesGetCommandTestCase | Тест на `spamfighter.api.message.firewall.FirewallRulesGetCommand`.
Class | FirewallRulesSetCommandTestCase | Тест на `spamfighter.api.message.firewall.FirewallRulesSetCommand`.
Class | FirewallRulesCheckCommandTestCase | Тест на `spamfighter.api.message.firewall.FirewallRulesCheckCommand`.